@@ -5,11 +5,10 @@ use warnings;
 use base qw( Catalyst::Controller Class::Accessor::Fast );
 
 use HTML::FormFu;
-use HTML::FormFu::Preload;
 use Scalar::Util qw/ weaken /;
 use Carp qw/ croak /;
 
-our $VERSION = '0.01001';
+our $VERSION = '0.01002';
 $VERSION = eval $VERSION;  # see L<perlmodstyle>
 
 __PACKAGE__->mk_accessors(qw( _html_formfu_config ));
@@ -85,6 +84,8 @@ sub _form {
                      { $self->{c}->uri_for( split( '\s*,\s*', $1 ) ) }eg
                 }
             });
+            
+            weaken( $self->{c} );
     }
     
     if ( $config->{languages_from_context} ) {
